/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import org.netbeans.api.progress.ProgressHandle;

/**
 * Small class used to update a ProgressHandle by listening to property changes.
 * Simply pass a ProressHandle, property name that indicates a change in
 * progress and a property name that indicates a finished state.
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class ProgressListener implements PropertyChangeListener {

    private ProgressHandle handle;
    private String progressPropertyName;
    private String finishPropertyName;

    public ProgressListener(ProgressHandle handle, String progressPropertyName, String finishPropertyName) {
        this.handle = handle;
        this.progressPropertyName = progressPropertyName;
        this.finishPropertyName = finishPropertyName;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if (progressPropertyName.equalsIgnoreCase(evt.getPropertyName())) {
            handle.progress((Integer) evt.getNewValue());
        } else if (finishPropertyName.equalsIgnoreCase(evt.getPropertyName())) {
            handle.finish();
        }
    }
}
