/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.util;

/**
 * Unit of measure.
 * 
 * TODO: have a look at javax.measure.*
 * 
 * @author johan
 */
public enum UOM {
    NOT_SPECIFIED(Dimension.NOT_SPECIFIED, "Not specified"),
    /**
     * 1/m2 - Amount per area unit
     */
    AMOUNT_PER_M2(Dimension.AMOUNT_PER_AREA, "1/m2"),
    /**
     * 1/second - Amount per time unit
     */
    AMOUNT_PER_SECOND(Dimension.AMOUNT_PER_TIME, "1/s"),
    /**
     * 1 - Amount/Count
     */
    COUNT(Dimension.AMOUNT, "Amount/Count"),
    /**
     * Millimeter
     */
    MM(Dimension.LENGTH, "mm"),
    /**
     * Centimeter
     */
    CM(Dimension.LENGTH, "cm"),
    /**
     * square meter 
     */
    M2(Dimension.AREA, "m2"),
    /**
     * ml - Capacity large
     */
    ML(Dimension.VOLUME, "ml"),
    /**
     * L - Capacity count
     */
    LITERS(Dimension.VOLUME, "L"),
    /**
     * mm2/s - Area per time unit
     */
    MM2_PER_SECOND(Dimension.AREA_PER_TIME,"mm2/s"),
    MM3_PER_M2(Dimension.VOLUME_PER_AREA, "mm3/m2"),
    MM3_PER_M3(Dimension.VOLUME_PER_VOLUME, "mm3/m3"),
    MM3_PER_KG(Dimension.VOLUME_PER_MASS, "mm3/kg"),
    /**
     * mm3/second - Flow
     */
    MM3_PER_SECOND(Dimension.VOLUME_PER_TIME, "mm3/s"),
    L_PER_HA(Dimension.VOLUME_PER_AREA, "L/Ha"),
    /**
     * ml/m2 - Capacity per area large
     */
    ML_PER_M2(Dimension.VOLUME_PER_AREA, "ml/m2"),
    /**
     * ml/s - Float large
     */
    ML_PER_SEC(Dimension.VOLUME_PER_TIME, "ml/s"),
    
    MG_PER_M2(Dimension.MASS_PER_AREA, "mg/m2"),
    MG_PER_KG(Dimension.MASS_PER_MASS, "mg/kg"),
    /**
     * Milligram per second = Mass flow
     */
    MG_PER_SECOND(Dimension.MASS_PER_TIME, "mg/s"),
    /**
     * mg/l - Mass per capacity unit
     */
    MG_PER_L(Dimension.MASS_PER_VOLUME,"mg/l"),
    KG_PER_HA(Dimension.MASS_PER_AREA, "kg/Ha"),
    /**
     * g - Mass large
     */
    GRAM(Dimension.MASS,"g"),
    /**
     * Kilogram
     */
    KG(Dimension.MASS,"kg"),
    
    /**
     * Second
     */
    SECOND(Dimension.TIME, "s"),
    /**
     * Milli second
     */
    MS(Dimension.TIME, "ms"),
    /**
     * ppm - Parts per million
     */
    PARTS_PER_MILLION(Dimension.AMOUNT, "ppm"),
    /**
     * ° - Angle
     */
    ANGLE(Dimension.DEGREES,"°")
    ;
    
    private Dimension dimension;
    private String label;

    private UOM(Dimension dimension, String label) {
        this.dimension = dimension;
        this.label = label;
    }

    public Dimension getDimension() {
        return dimension;
    }

    public String getLabel() {
        return label;
    }

    @Override
    public String toString() {
        return label;
    }
    
    
    
    // UOMs with the same dimension can be converted from one to the other.
    // TODO (low prio): set up conversion factor lookup.
    public enum Dimension {
        NOT_SPECIFIED,
        AMOUNT_PER_AREA,
        AMOUNT_PER_TIME,
        AMOUNT,
        LENGTH,
        MASS,
        AREA,
        AREA_PER_TIME,
        TIME,
        VOLUME,
        MASS_PER_AREA,
        MASS_PER_MASS,
        MASS_PER_TIME,
        MASS_PER_VOLUME,
        VOLUME_PER_AREA,
        VOLUME_PER_VOLUME,
        VOLUME_PER_MASS,
        VOLUME_PER_TIME,
        DEGREES
        ;
    }
}
